Intro to Riptable
*****************

Welcome to Riptable. This intro guide is intended to help get you familiar with Riptable's basic functionality and syntax.

Questions or suggestions? Email RiptableDocumentation@sig.com.


.. toctree::
   :maxdepth: 1
   
   tutorial_intro
   tutorial_datasets
   tutorial_filters
   tutorial_datetimes
   tutorial_categoricals
   tutorial_accums
   tutorial_concat
   tutorial_merge
   tutorial_reshape
   tutorial_visualize
   tutorial_missing_data
   tutorial_sample_data
   tutorial_io
   tutorial_performance
   RiptableExercises
   RiptableSolutions
   
Appendix
--------
.. toctree::
   :maxdepth: 1
   
   tutorial_numpy_rt
   tutorial_cat_reduce
   
   